@@ -86,7 +86,7 @@ class InelsMqtt:
         _t = config.get(MQTT_TIMEOUT)
         self.__timeout = _t if _t is not None else __DISCOVERY_TIMEOUT__
 
-        self.__data_changed = dict[str, Callable[[Any], Any]]()
+        self._listeners = dict[str, Callable[[Any], Any]]()
         self.__try_connect = False
         self.__message_readed = False
         self.__messages = dict[str, str]()
@@ -131,11 +131,9 @@ class InelsMqtt:
 
         return self.__is_available
 
-    def append_data_change_listener(
-        self, topic: str, fnc: Callable[[Any], Any]
-    ) -> None:
+    def subscribe_listener(self, topic: str, fnc: Callable[[Any], Any]) -> None:
         """Append new item into the datachange listener."""
-        self.__data_changed[topic] = fnc
+        self._listeners[topic] = fnc
 
     def __connect(self) -> None:
         """Create connection and register callback function to neccessary
@@ -345,9 +343,9 @@ class InelsMqtt:
         if device_type in DEVICE_TYPE_DICT:
             self.__messages[msg.topic] = msg.payload
 
-        if not self.__data_changed and msg.topic in self.__data_changed:
+        if len(self._listeners) > 0 and msg.topic in self._listeners:
             # This pass data change directely into the device.
-            self.__data_changed[msg.topic](msg.payload)
+            self._listeners[msg.topic](msg.payload)
 
     def __on_subscribe(
         self,
